@@ -68,9 +68,9 @@ class Episode(object):
             if not 'There is no summary added for this episode' in page:
                 try:
                     summary = re.search(
-                        r"<table width='100%'><tr><td>(.*?)<br>", page, 
+                        r"</table>(.*?)<br>&nbsp;</td>", page, 
                         re.MULTILINE).group(1).strip()
-                    return summary
+                    return unicode(summary, 'utf-8')
                 except Exception, e:
                     print('Episode.summary: %s, %s' % (self, e))
         except URLError, e:
